window.Gleam.initSearch([{"doc":"nephrotoma","title":"nephrotoma","content":"# Nephrotoma\n\n[![Package Version](https://img.shields.io/hexpm/v/nephrotoma)](https://hex.pm/packages/nephrotoma)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/nephrotoma/)\n\n```sh\ngleam add nephrotoma@1\n```\n```gleam\nimport nephrotoma\nimport gleam/string\n\npub fn main() {\n  let tree = nephrotoma.from_list(string.to_graphemes(&quot;hello, world!&quot;))\n  |&gt; nephrotoma.append_list(string.to_graphemes(&quot;hi!&quot;))\n  let assert True = nephrotoma.exists(tree, &quot;hello, world!&quot;)\n  let assert False = nephrotoma.exists(tree, &quot;hello&quot;)\n}\n```\n\n## What is this for?\n\nThis is a library for checking whether a list exists in a list of lists.\n\n### Why not just check one by one?\n\nChecking one by one can be expensive. This library is designed for if you need to perform a large amount of checks.\n\n### So I should always use this?\n\nCreating the initial tree is also expensive, so this may not be fit for the job. **Also, this was made in an afternoon. It is not at all optimized.**\n\n## What does Nephrotoma mean?\n\n[It&#39;s a genus of crane flies.](https://en.wikipedia.org/wiki/Nephrotoma)\n\n### Why did you name a project off of a genus of crane flies?\n\nI don&#39;t know. They have long legs, I guess, reminding me of trees?\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"nephrotoma","title":"OrderedTree","content":"pub type OrderedTree(key) {\n  OrderedTree(children: Dict(key, OrderedTreeNode(key)))\n}\n The start of a tree, containing only a dictionary of child nodes.\n\nOrderedTree(children: Dict(key, OrderedTreeNode(key)))\n\n\nSynonyms:\nnephrotoma.OrderedTree\nnephrotoma OrderedTree","url":"nephrotoma.html#OrderedTree"},{"doc":"nephrotoma","title":"OrderedTreeNode","content":"pub type OrderedTreeNode(key) {\n  OrderedTreeNode(\n    children: Dict(key, OrderedTreeNode(key)),\n    exists: Bool,\n  )\n}\n A node, containing a dictionary of child nodes and a boolean value signifying whether this, too, is an endpoint.\n\nOrderedTreeNode(\n  children: Dict(key, OrderedTreeNode(key)),\n  exists: Bool,\n)\n\n\nSynonyms:\nnephrotoma.OrderedTreeNode\nnephrotoma OrderedTreeNode","url":"nephrotoma.html#OrderedTreeNode"},{"doc":"nephrotoma","title":"append_child_to_node","content":"pub fn append_child_to_node(\n  node: OrderedTreeNode(a),\n  key: a,\n  child: OrderedTreeNode(a),\n) -&gt; OrderedTreeNode(a)\n\nSynonyms:\nnephrotoma.append_child_to_node\nnephrotoma append_child_to_node","url":"nephrotoma.html#append_child_to_node"},{"doc":"nephrotoma","title":"append_list","content":"pub fn append_list(\n  tree: OrderedTree(a),\n  list: List(a),\n) -&gt; OrderedTree(a)\n Add a path as existing to a tree.\n \n new()\n |&gt; append_list([1, 2, 3])\n |&gt; exists([1, 2, 3])\n // -&gt; True\n \nSynonyms:\nnephrotoma.append_list\nnephrotoma append_list","url":"nephrotoma.html#append_list"},{"doc":"nephrotoma","title":"append_list_to_node","content":"pub fn append_list_to_node(\n  node: OrderedTreeNode(a),\n  list: List(a),\n) -&gt; OrderedTreeNode(a)\n Add a path as existing in a node.\n \n new_node(False)\n |&gt; append_list_to_node([1, 2, 3])\n |&gt; exists_in_node([1, 2, 3])\n // -&gt; True\n \nSynonyms:\nnephrotoma.append_list_to_node\nnephrotoma append_list_to_node","url":"nephrotoma.html#append_list_to_node"},{"doc":"nephrotoma","title":"exists","content":"pub fn exists(tree: OrderedTree(a), path: List(a)) -&gt; Bool\n Check whether a path exists in a node.\n Always returns false if either the node or inputted path are empty.\n \n let tree = from_list([1, 2, 3])\n tree |&gt; exists([1, 2, 3])\n // -&gt; True\n tree |&gt; exists([1, 2])\n // -&gt; False\n tree |&gt; exists([1, 2, 3, 4])\n // -&gt; False\n tree |&gt; exists([])\n // -&gt; False\n \nSynonyms:\nnephrotoma.exists\nnephrotoma exists","url":"nephrotoma.html#exists"},{"doc":"nephrotoma","title":"exists_in_node","content":"pub fn exists_in_node(\n  node: OrderedTreeNode(a),\n  path: List(a),\n) -&gt; Bool\n Check whether a path exists in a node.\n Always returns false if either the node or inputted path are empty.\n \n let node = node_from_list([1, 2, 3])\n node |&gt; exists_in_node([1, 2, 3])\n // -&gt; True\n node |&gt; exists_in_node([1, 2])\n // -&gt; False\n node |&gt; exists_in_node([1, 2, 3, 4])\n // -&gt; False\n node |&gt; exists_in_node([])\n // -&gt; False\n \nSynonyms:\nnephrotoma.exists_in_node\nnephrotoma exists_in_node","url":"nephrotoma.html#exists_in_node"},{"doc":"nephrotoma","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; OrderedTree(a)\n Equivalent to creating a now tree and adding a path.\n \n from_list([1, 2, 3])\n |&gt; exists([1, 2, 3])\n // -&gt; True\n \nSynonyms:\nnephrotoma.from_list\nnephrotoma from_list","url":"nephrotoma.html#from_list"},{"doc":"nephrotoma","title":"from_node","content":"pub fn from_node(node: OrderedTreeNode(a)) -&gt; OrderedTree(a)\n Create a tree given a node.\n \n node_from_list([1, 2, 3])\n |&gt; from_node()\n |&gt; exists([1, 2, 3])\n // -&gt; True\n \nSynonyms:\nnephrotoma.from_node\nnephrotoma from_node","url":"nephrotoma.html#from_node"},{"doc":"nephrotoma","title":"new","content":"pub fn new() -&gt; OrderedTree(a)\n Create an empty ordered tree.\n \n let tree = new()\n \nSynonyms:\nnephrotoma.new\nnephrotoma new","url":"nephrotoma.html#new"},{"doc":"nephrotoma","title":"new_node","content":"pub fn new_node(exists: Bool) -&gt; OrderedTreeNode(a)\n Create an empty node of an ordered tree, specifying whether the node exists.\n \n let node = new_node(True)\n node.exists\n // -&gt; True\n \nSynonyms:\nnephrotoma.new_node\nnephrotoma new_node","url":"nephrotoma.html#new_node"},{"doc":"nephrotoma","title":"node_from_list","content":"pub fn node_from_list(list: List(a)) -&gt; OrderedTreeNode(a)\n Equivalent to creating a new node and adding a path.\n \n node_from_list([1, 2, 3])\n |&gt; exists_in_node([1, 2, 3])\n // -&gt; True\n \nSynonyms:\nnephrotoma.node_from_list\nnephrotoma node_from_list","url":"nephrotoma.html#node_from_list"},{"doc":"nephrotoma","title":"node_from_tree","content":"pub fn node_from_tree(tree: OrderedTree(a)) -&gt; OrderedTreeNode(a)\n Create a nonexistant node given a tree.\n \n from_list([1, 2, 3])\n |&gt; node_from_tree()\n |&gt; exists_in_node([1, 2, 3])\n // -&gt; True\n \nSynonyms:\nnephrotoma.node_from_tree\nnephrotoma node_from_tree","url":"nephrotoma.html#node_from_tree"},{"doc":"nephrotoma","title":"update_children","content":"pub fn update_children(\n  node: OrderedTreeNode(a),\n  f: fn(Dict(a, OrderedTreeNode(a))) -&gt;\n    Dict(a, OrderedTreeNode(a)),\n) -&gt; OrderedTreeNode(a)\n Run a function on the children of a node.\n \n node_from_list([1, 2, 3])\n |&gt; update_children(fn(children) { children |&gt; dict.insert(4, new_node(True)) })\n |&gt; exists_in_node([1, 4])\n // -&gt; True\n \nSynonyms:\nnephrotoma.update_children\nnephrotoma update_children","url":"nephrotoma.html#update_children"},{"doc":"nephrotoma","title":"nephrotoma","content":" Nephrotoma is a library for creating a tree and querying whether a node exists at a path. \\\n The head of a tree contains only a dictionary of child nodes.\n Each node contains a boolean that signifies that this is an endpoint and a dictionary of child nodes.\n This tree:\n ```text\n       +---------------+\n       | children:     |\n       | 1, 4          |\n       +-+--+----------+\n         |  |\n         |  +---------------+\n         |                  |\n +---------------+  +---------------+\n | exists: True  |  | exists: False |\n | children:     |  | children:     |\n | (none)        |  | 8             |\n +---------------+  +-+-------------+\n                      |\n              +---------------+\n              | exists: True  |\n              | children:     |\n              | 11, 12        |\n              +-+---+---------+\n                |   |\n        +-------+   +-------+\n        |                   |\n +---------------+  +---------------+\n | exists: True  |  | exists: True  |\n | children:     |  | children:     |\n | (none)        |  | (none)        |\n +---------------+  +---------------+\n ```\n could be created with:\n ```gleam\n let tree = nephrotoma.from_list([1])\n |&gt; nephrotoma.append_list([4, 8])\n |&gt; nephrotoma.append_list([4, 8, 11])\n |&gt; nephrotoma.append_list([4, 8, 12])\n ```\n and could be checked with:\n ```gleam\n tree |&gt; nephrotoma.exists([4, 8])\n // -&gt; True\n tree |&gt; nephrotoma.exists([4, 8, 11])\n // -&gt; True\n tree |&gt; nephrotoma.exists([1, 9])\n // -&gt; False\n tree |&gt; nephrotoma.exists([4])\n // -&gt; False\n tree |&gt; nephrotoma.exists([])\n // -&gt; False\n ```","url":"nephrotoma.html"}]);